#ifndef ABSTRACT_DMA_H
#define ABSTRACT_DMA_H

#include <stm32f0xx.h>
#include "abstract-dma-init.hpp"

namespace stm32f072xb {

class AbstractDma {
   public:
	AbstractDma(DMA_Channel_TypeDef* dmaChannel, AbstractDmaInit& dmaInit);
	~AbstractDma();
	void start();
	void stop();

	void setMemory(volatile const uint8_t* buffer);
	void setNumberOfDataTransfer(uint16_t numberOfDataTransfer);

   protected:
	void setupRegister();

   private:
	void setPeripheralIncrement(DmaPeripheralIncrement peripheralIncrement);
	void setPeripheralSize(DmaPeripheralSize peripheralSize);
	void setMemoryIncrement(DmaMemoryIncrement memoryIncrement);
	void setMemorySize(DmaMemorySize memorySize);
	void setCircularMode(DmaCircularMode circularMode);
	void setDirection(DmaDirection direction);
	void setPeripheral(DmaPeripheral peripheral);

	DMA_Channel_TypeDef* _dmaChannel;
	AbstractDmaInit& _dmaInit;
};

}  // namespace stm32f072xb

#endif
